@@ -19,6 +19,8 @@ from pypgatk.commands import vcf_to_proteindb as vcf_to_proteindb_cmd
 from pypgatk.commands import dnaseq_to_proteindb as dnase_to_proteindb_cmd
 from pypgatk.commands import proteindb_decoy as proteindb_decoy_cmd
 from pypgatk.commands import peptide_class_fdr as peptide_class_fdr_cmd
+from pypgatk.commands import msrescore as msrescore_configuration_cmd
+from pypgatk.commands import deeplc as deeplc_cmd
 
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 
@@ -42,6 +44,8 @@ cli.add_command(dnase_to_proteindb_cmd.dnaseq_to_proteindb)
 cli.add_command(proteindb_decoy_cmd.generate_database)
 cli.add_command(proteindb_decoy_cmd.generate_database)
 cli.add_command(peptide_class_fdr_cmd.peptide_class_fdr)
+cli.add_command(msrescore_configuration_cmd.msrescore_configuration)
+cli.add_command(deeplc_cmd.generate_deeplc)
 
 def main():
   cli()
